import os
from . import utils
import sys
import time


def strong_arrange(root, destination, index, warn=True):
    """
    Deploys strong arrange function that arranges files
    from current folder and subfolders into specified categories

    """
    if warn is True:
        print(
            "You are going to strong arrange",
            f"the directory {root}.",
            "It will rearrange all the files",
            "in the subfolders as well.",
            "It might cause issues if you",
            "have added wrong extensions",
            "in the config.ini file and run",
            "the program in a sensitive directory.",
            "You still have 7 seconds to",
            "cancel it if you want to review anything.",
            "\n(Press Ctrl+C to abort)",
        )
        try:
            time.sleep(7)
        except KeyboardInterrupt:
            sys.exit()

    TOTAL_COUNT = {}
    for foldername, subfolder, filenames in os.walk(root):
        for file in filenames:
            if os.path.isfile(os.path.join(foldername, file)):
                status, types = lib.utils.startProcess(
                    foldername, file, index, destination
                )
                if types in TOTAL_COUNT:
                    TOTAL_COUNT[types] = TOTAL_COUNT[types] + 1
                else:
                    TOTAL_COUNT[types] = 1
    return TOTAL_COUNT


def weak_arrange(root, destination, index):
    """
    Deploys weak arrange function that arranges files only
    from current folder into specified categories

    """
    TOTAL_COUNT = {}
    for file in os.listdir(root):
        if os.path.isfile(os.path.join(root, file)):
            status, types = lib.utils.startProcess(root, file, index, destination)
            if types in TOTAL_COUNT:
                TOTAL_COUNT[types] = TOTAL_COUNT[types] + 1
            else:
                TOTAL_COUNT[types] = 1
    return TOTAL_COUNT



# ArrangePy
# Arranges the files according to their types for later classification
# https://github.com/prashantsengar/ArrangePy
# https://t.me/joinchat/INDdLlDf-SFDPURESGgdrQ

import os
import sys
from . import func
from . import utils
from . import web as webapp

import argparse


RESULT_DIR = "ArrangedPy"
FOLDER_TYPES = utils.configure()

class CHOICES:
    WEAK = 1
    STRONG = 2
    EXIT = 0

def run(root, choice=None, warn_for_strong=True):
    TARGET_FOLDER = root
    destination = os.path.join(TARGET_FOLDER, RESULT_DIR)
    # print(destination)
    utils.makeFolders(destination, FOLDER_TYPES.keys())

    print("---ArrangePy---")
    print("Cleaning: ", root)

    if choice is None:
        choice = int(
            input(
                "Press [1]: for Weak arrange"
                + "\nPress [2]: for Strong arrange"
                + "\nPress [0]: to exit\nOption: "
            )
        )

    if choice == CHOICES.WEAK:
        res = func.weak_arrange(root, destination, FOLDER_TYPES)
    elif choice == CHOICES.STRONG:
        res = func.strong_arrange(root, destination, FOLDER_TYPES, warn_for_strong)
    elif choice == CHOICES.EXIT:
        return
    else:
        print("Incorrect Input")
        return

    # Final Result
    message = "Result"
    others = "Others(Not_moved)"
    print(f"{message:*^30s}")
    for key, value in res.items():
        if key == others:
            continue
        print(f"{value} file moved into Category {key}")
    if others in res:
        print(f"{res[others]} file Not moved")

def main():
    parser = argparse.ArgumentParser()

    exclusive_group = parser.add_mutually_exclusive_group()

    exclusive_group.add_argument(
        "-w", "--weak", action="store_true", required=False, help="Weak arrange"
    )
    exclusive_group.add_argument(
        "-s", "--strong", action="store_true", required=False, help="Strong arrange"
    )
    exclusive_group.add_argument(
        "-b", "--web", action="store_true", required=False, help="Run web GUI"
    )

    parser.add_argument(
        "directory",
        nargs="?",
        help="The directory to arrange, default is current working directory",
    )
    parser.add_argument(
        "-nw",
        "--no-warning",
        action="store_true",
        required=False,
        help="Don't show any warnings when running strong arrange",
    )

    args = parser.parse_args()
    target = os.getcwd()

    if args.directory:
        target = args.directory
    if args.web:
        webapp.main(target=target)
    elif args.weak:
        run(target, choice=CHOICES.WEAK)
    elif args.strong:
        run(target, choice=CHOICES.STRONG, warn_for_strong=args.no_warning)
    else:
        run(target)


if __name__ == "__main__":
    main()



from flask import Flask, render_template, request, redirect, url_for, make_response
##from arrangepy.main import RESULT_DIR, FOLDER_TYPES
from . import func
from . import utils
import webbrowser
import os
import platform
import subprocess
import logging
logging.basicConfig(filename='.server.log', filemode='w')

import sys

RESULT_DIR = "ArrangedPy"
FOLDER_TYPES = utils.configure()

cli = sys.modules['flask.cli']
cli.show_server_banner = lambda *x: None


app = Flask(__name__)

portNumber = 45269
linkofPage = "http://127.0.0.1:" + str(portNumber)

TARGET_FOLDER = '.'

def gettheAddress():
    """Read cache file and create target folder"""
    temp = request.cookies.get("directory")
    if temp is None:
        address = TARGET_FOLDER
    else:
        address = temp
    return address


def startwork(TARGET):
    """Create folders to keep files according to their file types"""
    destination = os.path.join(TARGET, RESULT_DIR)
    utils.makeFolders(destination, FOLDER_TYPES.keys())
    return destination


@app.route("/dashboard/")
def dashboard():
    """Scan the location for items"""
    address = gettheAddress()
    dataPacket = {}
    Elements = list(os.scandir(address))
    dataPacket["folder_count"] = len([1 for x in Elements if x.is_dir()])
    dataPacket["file_count"] = len([1 for x in Elements if x.is_file()])
    dataPacket["total_items"] = len(Elements)
    dataPacket["address"] = address
    return render_template("index.html", data=dataPacket, url=linkofPage)


@app.route("/input", methods=["POST", "GET"])
def inputuser():
    """Take the input of the address from HTML methods"""
    if request.method == "POST":
        val = request.form["newaddress"]
    else:
        val = request.args.get("newaddress")
    if os.path.isdir(val):
        resp = make_response(redirect(url_for("dashboard")))
        resp.set_cookie("directory", str(val))
        return resp
    return render_template("error404.html", url=linkofPage + "/changelocation")


@app.route("/changelocation")
def changingPage():
    """Ask for the location to do the cleaning work"""
    return render_template("change.html", url=linkofPage)


def open_file(path):
    """Open the file in explorer"""
    if platform.system() == "Windows":
        os.startfile(path)
    elif platform.system() == "Darwin":
        subprocess.Popen(["open", path])
    else:
        subprocess.Popen(["xdg-open", path])


@app.route("/openlocation")
def openlocation():
    """Open the destination location in explorer"""
    address = gettheAddress()
    path = os.path.join(address, RESULT_DIR)
    open_file(path)
    response = make_response(redirect(url_for("dashboard")))
    return response


@app.route("/dashboard/standardscan")
def standardScan():
    """Initiate the arrange and redirect to report page"""
    TARGET_DIR = gettheAddress()
    destination = startwork(TARGET_DIR)
    report = func.weak_arrange(TARGET_DIR, destination, FOLDER_TYPES)
    others = "Others(Not_moved)"
    if others not in report:
        if len(report) == 0:
            report[others] = "No file to move,"
        else:
            report[others] = 0
    return render_template("completed.html", res=report, url=linkofPage)


@app.route("/dashboard/deepscan")
def deepScan():
    """Initiate the strong arrange and redirect to report page"""
    TARGET_DIR = gettheAddress()
    destination = startwork(TARGET_DIR)
    report = func.strong_arrange(TARGET_DIR, destination, FOLDER_TYPES)
    others = "Others(Not_moved)"
    if others not in report:
        if len(report) == 0:
            report[others] = "No file to move,"
        else:
            report[others] = 0
    return render_template("completed.html", res=report, url=linkofPage)


@app.route("/dashboard/quit")
def close():
    """Turn the web server OFF"""
    return """Server shutting down.., close this browser tab
    and close the python compiler by using ctrl+c"""


def main(target=None):
    if target is None:
        target = os.getcwd()
    global TARGET_FOLDER
    TARGET_FOLDER = target
    webbrowser.open(linkofPage + "/dashboard")
    app.run("localhost", port=portNumber, debug=False)


if __name__ == "__main__":
    print("Running the program..")
    main()



from setuptools import setup
import os

def readme():
    with open('README.md') as file:
        return file.read()

setup(name='arrangepy',
      version='1.1.1',
      description='Arrange your files in distinct folder',
      long_description=readme(),
      long_description_content_type = 'text/markdown',
      keywords='arrange files windows cleaning tool open source prashant sengar',
      url='https://github.com/prashantsengar/ArrangePy',
      author='Prashant Sengar',
      author_email='prashantsengar5@gmail.com',
      license='MIT',
      packages=['arrangepy'],
##      scripts=['bin/arrange'],
      install_requires=[
          'flask',
      ],
      entry_points={
          'console_scripts': ['arrange=arrangepy.main:main'],
      },
      include_package_data=True,
      zip_safe=False)



import os
import shutil
import configparser
import re


def startProcess(folder, file, index, root_dst):
    """
    Accept file name and parent folder_name(folder)
    Return a Tuple(TRUE|FALSE,TYPE_OF_FILE)

    """
    src = os.path.join(folder, file)
    ext = os.path.splitext(file)[1].lower()
    dst_folder = identifyType(ext, index)
    if dst_folder is not None:
        dst = os.path.join(root_dst, dst_folder)
        return moveFiles(src, dst), dst_folder
    return False, "Others(Not_moved)"


def moveFiles(src, dst):
    """
    Accept source and destination and move files .
    Return True if File is Copied other wise False

    """
    try:
        shutil.move(src, dst)
        res = True
    except:
        res = False
    return res


def identifyType(ext, lst):
    """
    Accept extenssion Example .pdf .mp4 and
    return a category type from FOLDER_TYPES Dictionary

    """
    for (key, value) in lst.items():
        if ext[1:] in value:
            return key
    return None


def makeFolders(root, lst):
    """
    Accept A List of Folder name and
    create that category name folder in RESULT_DIR

    """
    if os.path.exists(root) is False:
        os.makedirs(root)
    print(os.path.abspath(root))

    for name in lst:
        if name not in os.listdir(root):
            os.makedirs(os.path.join(root, name))


def configure():
    """
    Read configuration file and create index of
    extentions with respect to their folder types

    """
    config = configparser.ConfigParser()
    config.read("config.ini")
    extension = config["ext"]
    p = re.compile(r"\'(.*?)\'")
    FOLDER_TYPES = {key: extension[key] for key in extension}
    for key in FOLDER_TYPES:
        FOLDER_TYPES[key] = p.findall(FOLDER_TYPES[key])

    return FOLDER_TYPES
